systemtools.TestManager
=======================

.. abjad-lineage:: abjad.tools.systemtools.TestManager.TestManager

.. autoclass:: abjad.tools.systemtools.TestManager.TestManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.TestManager.TestManager.apply_additional_layout
      ~abjad.tools.systemtools.TestManager.TestManager.compare
      ~abjad.tools.systemtools.TestManager.TestManager.compare_files
      ~abjad.tools.systemtools.TestManager.TestManager.get_current_function_name
      ~abjad.tools.systemtools.TestManager.TestManager.read_test_output
      ~abjad.tools.systemtools.TestManager.TestManager.test_function_name_to_title_lines
      ~abjad.tools.systemtools.TestManager.TestManager.write_test_output

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.apply_additional_layout
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.compare
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.compare_files
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.get_current_function_name
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.read_test_output
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.test_function_name_to_title_lines
   :noindex:

.. automethod:: abjad.tools.systemtools.TestManager.TestManager.write_test_output
   :noindex:
